
# Slot: decreases transport of


holds between two molecular entities where the action or effect of one decreases the rate of transport of the other across some boundary in a system of interest

URI: [biolink:decreases_transport_of](https://w3id.org/biolink/vocab/decreases_transport_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects transport of](affects_transport_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:decreases_transport_of |

